# data_io

Save and load data in multiple formats (CSV, pickle, compressed pickle, JSON) with automatic directory creation, elapsed-time logging, and file-size reporting.

See {doc}`../examples/data_io` for usage examples.

## API Reference

```{eval-rst}
.. automodule:: pyedautils.data_io
   :members:
   :undoc-members:
   :show-inheritance:
```
